@@ -1,4 +1,5 @@
 from IPython.display import display
+from packaging import version
 
 import collections
 import ipywidgets
@@ -9,6 +10,10 @@ import re
 import traitlets
 
 
+# We are providing some compatibility for ipywidgets v7 and v8
+IS_VERSION_8 = version.parse(ipywidgets.__version__) >= version.parse("8")
+
+
 class FormError(Exception):
     pass
 
@@ -196,9 +201,15 @@ class Form:
         titles = []
         if label is not None or "title" in schema:
             titles = [schema.get("title", label)]
-        accordion = ipywidgets.Accordion(
-            children=[ipywidgets.VBox(widget_list)], titles=titles
-        )
+
+        if IS_VERSION_8:
+            accordion = ipywidgets.Accordion(
+                children=[ipywidgets.VBox(widget_list)], titles=titles
+            )
+        else:
+            accordion = ipywidgets.Accordion(children=[ipywidgets.VBox(widget_list)])
+            for i, title in enumerate(titles):
+                accordion.set_title(i, title)
 
         # This folds the accordion
         accordion.selected_index = None
@@ -266,7 +277,7 @@ class Form:
                 0,
                 ipywidgets.Label(
                     title,
-                    label=ipywidgets.Layout(width="100%"),
+                    layout=ipywidgets.Layout(width="100%"),
                     tooltip=tooltip,
                 ),
             )
@@ -345,6 +356,9 @@ class Form:
         return self._construct_simple(schema, ipywidgets.Text(), label=label)
 
     def _construct_number(self, schema, label=None, root=False):
+        kwargs = dict()
+        if "multipleOf" in schema:
+            kwargs["step"] = schema["multipleOf"]
         # Inputs bounded only from below or above are currently not supported
         # in ipywidgets - rather strange
         if "minimum" in schema and "maximum" in schema:
@@ -355,14 +369,17 @@ class Form:
             )
             return self._construct_simple(
                 schema,
-                _class(min=schema["minimum"], max=schema["maximum"]),
+                _class(min=schema["minimum"], max=schema["maximum"], **kwargs),
                 label=label,
             )
         else:
-            widget = minmax_schema_rule(ipywidgets.FloatText(), schema)
+            widget = minmax_schema_rule(ipywidgets.FloatText(**kwargs), schema)
             return self._construct_simple(schema, widget, label=label)
 
     def _construct_integer(self, schema, label=None, root=False):
+        kwargs = dict()
+        if "multipleOf" in schema:
+            kwargs["step"] = schema["multipleOf"]
         # Inputs bounded only from below or above are currently not supported
         # in ipywidgets - rather strange
         if "minimum" in schema and "maximum" in schema:
@@ -371,11 +388,11 @@ class Form:
             )
             return self._construct_simple(
                 schema,
-                _class(min=schema["minimum"], max=schema["maximum"]),
+                _class(min=schema["minimum"], max=schema["maximum"], **kwargs),
                 label=label,
             )
         else:
-            widget = minmax_schema_rule(ipywidgets.IntText(), schema)
+            widget = minmax_schema_rule(ipywidgets.IntText(**kwargs), schema)
             return self._construct_simple(schema, widget, label=label)
 
     def _construct_boolean(self, schema, label=None, root=False):
